@@ -45,8 +45,8 @@ path_objects_dir <- function(path_store) {
 #' @return Character of length,
 #'   default pseudo-directory path of target data in the cloud.
 #' @examples
-#' path_objects_dir_cloud()
-path_objects_dir_cloud <- function() {
+#' tar_path_objects_dir_cloud()
+tar_path_objects_dir_cloud <- function() {
   file.path(path_store_default(), "objects", fsep = "/")
 }
 
