@@ -17,7 +17,7 @@ tar_test("run verbose reporter with a error and save workspace", {
   expect_error(expect_message(local$run()), class = "tar_condition_run")
 })
 
-tar_test("run timestamp reporter with a warning", {
+tar_test("run verbose reporter with a warning", {
   pipeline <- pipeline_init(list(target_init("x", quote(warning(123)))))
   local <- local_init(pipeline, reporter = "verbose")
   suppressWarnings(
